import React, {useEffect, useState} from "react";
import {Button, Card, Col, Input, message, Modal, Row, Space, Table, Tag} from "antd";
import {useStore} from "../../utils/useStore";
import {observer} from "mobx-react-lite";
import {ExclamationCircleOutlined, FilterOutlined, PlusSquareOutlined,} from "@ant-design/icons";
import {MembershipModal} from "./MembershipModal";
import {BreadcumbComponent} from "../../component/BreadcumbComponent";

const {Search} = Input;

export const Membership = observer(() => {
  const store = useStore();
  const [visibleModal, setVisibleModal] = useState(false)
  const [initialData, setInitialData] = useState({})
  const [confirmLoading, setConfirmLoading] = useState(false);
  const [isLoading, setIsLoading] = useState(false);

  useEffect(() => {
    const init = async () => {
      try {
        setIsLoading(true)
        await store.membership.getData();
        setIsLoading(false)
      } catch (e) {
        setIsLoading(false)
      }
    }

    init()

  }, []);

  const columns = [
    {
      title: "Name",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "Username",
      dataIndex: "username",
      key: "username",
    },
    {
      title: "Status",
      dataIndex: "status",
      key: "status",
      render: (text, record) => (
          <>
            <Tag color="#E3E8EE" style={{color: "#4F566B"}}>
              Inactive
            </Tag>
            <Tag color="processing">Active</Tag>
          </>
      )
    },
    {
      title: "Action",
      key: "action",
      render: (text, record) => (
          <Space size="middle">
            <Button onClick={() => {
              setVisibleModal(true)
              setInitialData(record)
            }}>Edit</Button>
            <Button onClick={async () => {
              handleDelete(record.id)

            }}
            >Delete</Button>
          </Space>
      ),
    },
  ];

  const routeData = [
    {
      route: "/app/home",
      name: "Home",
    },
    {
      route: "/app/membership",
      name: <span style={{fontWeight: "bold"}}>Membership</span>,
    },
  ];

  const onSubmit = async (data) => {
    if (initialData.id) {
      setInitialData({})
      setConfirmLoading(true);
      try {
        await store.membership.update(initialData.id, data)
        message.success("Success Update Data Member")
      } catch (e) {
        message.error("Failed Update Data Member")
      }
      setConfirmLoading(false);
      setVisibleModal(false);
    } else {
      setInitialData({})
      setConfirmLoading(true);
      try {
        await store.membership.create(data)
        message.success("Success Add New Member")
      } catch (e) {
        console.log(e, "apa errornya")
        message.error("Failed Add Member")
      }
      setConfirmLoading(false);
      setVisibleModal(false);
    }
  }

  const handleDelete = (record) => {
    Modal.confirm({
      title: 'Are you sure reject this record?',
      icon: <ExclamationCircleOutlined/>,
      okText: 'Yes',
      okType: 'primary',
      cancelText: 'Cancel',
      onOk() {
        try {
          //TODO: minta apinya ke ka ilham ya, jangan di uncomment kalo pake api reconcile, nanti beneran ke apus datanya
          // await store.membership.delete(record.id)
          message.success('Success Delete Data')
        } catch (e) {
          message.error("Failed Delete Data")
        }
      },
      onCancel() {
        console.log('Cancel');
      },
    });
  }

  return (
      <div className={["ppob-container"].join(" ")}>
        <BreadcumbComponent data={routeData}/>
        <Card>
          <div>
            <Row style={{marginBottom: 20}}>
              <Col span={12}>
                <Button>
                  <FilterOutlined/>
                  Filter
                </Button>
              </Col>
              <Col span={12} style={{textAlign: "right"}}>
                <Search
                    placeholder="input search text"
                    style={{width: 200, marginRight: 10}}
                />
                <Button onClick={() => setVisibleModal(true)}>
                  <PlusSquareOutlined/> New
                </Button>
              </Col>
            </Row>
            <Table
                style={{textAlign: "center"}}
                columns={columns}
                dataSource={store.membership.data}
                bordered
                pagination={{
                  total: store.membership.total_data,
                  current: store.membership.page,
                  pageSize: store.membership.pageSize,
                  simple: true
                }} onChange={(page) => {
              store.membership.pageSize = page.pageSize;
              store.membership.page = page.current;
              store.membership.getData();
            }} current={store.membership.page}
                loading={store.membership.pageSize}/>
          </div>
        </Card>
        <MembershipModal visible={visibleModal}
                         confirmLoading={confirmLoading}
                         initialData={initialData}
                         onCreate={async (data) => {
                           onSubmit(data)
                         }}
                         onCancel={() => {
                           setInitialData({})
                           setVisibleModal(false);
                         }}/>
      </div>
  );
});
